emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

emacs-29 033071692c: ; Fix typos


From: Stefan Kangas
Subject: emacs-29 033071692c: ; Fix typos
Date: Fri, 16 Dec 2022 02:31:04 -0500 (EST)

branch: emacs-29
commit 033071692c7cd1cd550d25170d4b3168668567ac
Author: Stefan Kangas <stefankangas@gmail.com>
Commit: Stefan Kangas <stefankangas@gmail.com>

    ; Fix typos
---
 ChangeLog.2                                        |  2 +-
 ChangeLog.3                                        | 40 +++++++++++-----------
 doc/lispref/ChangeLog.1                            |  2 +-
 doc/lispref/modes.texi                             |  2 +-
 doc/lispref/sequences.texi                         |  2 +-
 lisp/ChangeLog.16                                  |  4 +--
 lisp/ChangeLog.17                                  |  2 +-
 lisp/epa-ks.el                                     |  2 +-
 lisp/gnus/ChangeLog.2                              |  2 +-
 lisp/gnus/ChangeLog.3                              |  2 +-
 lisp/org/ChangeLog.1                               |  2 +-
 lisp/progmodes/idlwave.el                          |  2 +-
 lisp/progmodes/js.el                               |  4 +--
 lisp/so-long.el                                    |  2 +-
 lisp/textmodes/toml-ts-mode.el                     |  2 +-
 lisp/treesit.el                                    |  6 ++--
 oldXMenu/ChangeLog.1                               |  2 +-
 src/ChangeLog.12                                   |  2 +-
 src/ChangeLog.13                                   |  2 +-
 src/fns.c                                          |  2 +-
 test/lisp/delim-col-tests.el                       |  2 +-
 test/lisp/emacs-lisp/cconv-tests.el                |  4 +--
 test/lisp/emacs-lisp/checkdoc-tests.el             | 12 +++----
 test/lisp/emacs-lisp/find-func-tests.el            |  2 +-
 .../erc/resources/services/auth-source/recon.eld   |  2 +-
 25 files changed, 54 insertions(+), 54 deletions(-)

diff --git a/ChangeLog.2 b/ChangeLog.2
index 143be59c9e..5d4c1afc36 100644
--- a/ChangeLog.2
+++ b/ChangeLog.2
@@ -28676,7 +28676,7 @@
        * lisp/faces.el (set-face-attribute): Don't be fooled too easily
        by a hyphen in a font's name.
 
-       Fix value of posn-at-pont in R2L lines
+       Fix value of posn-at-point in R2L lines
        * src/keyboard.c (Fposn_at_x_y, Fposn_at_point): Allow X pixel
        coordinate of -1, for a newline in a right-to-left line that
        overflowed into the left fringe.
diff --git a/ChangeLog.3 b/ChangeLog.3
index b162f96cb1..4b3507bae3 100644
--- a/ChangeLog.3
+++ b/ChangeLog.3
@@ -14724,7 +14724,7 @@
 
        * lisp/icomplete.el (icomplete-vertical-mode):
        (fido-vertical-mode): Tweak docstring.  Turn on
-       icomplete-mode. and fido-mdoe
+       icomplete-mode. and fido-mode
 
 2021-08-16  Glenn Morris  <rgm@gnu.org>
 
@@ -20654,7 +20654,7 @@
        * lisp/progmodes/cc-engine.el (c-clear-<-pair-props, 
c-clear->-pair-props)
        (c-clear-<-pair-props-if-match-after, 
c-clear->-pair-props-if-match-before)
        (c-forward-<>-arglist-recur):
-       Invalidate caches with c-trunctate-lit-pos-cache.
+       Invalidate caches with c-truncate-lit-pos-cache.
        (c-forward-<>-arglist-recur): If in a matching <...> expression, the < 
has a
        syntax-table property, but the > not, remove that property.
 
@@ -28297,7 +28297,7 @@
 
 2021-04-17  Eli Zaretskii  <eliz@gnu.org>
 
-       * src/emacs.c (load_pdump): Fix compilation on picky-complier platforms.
+       * src/emacs.c (load_pdump): Fix compilation on picky-compiler platforms.
 
 2021-04-17  Daniel Martín  <mardani29@yahoo.es>
 
@@ -29362,7 +29362,7 @@
        Make the function correctly recognize a brace block preceded by an
        introductory line without a parameter list.
 
-       * lisp/progmodes/cc-cmds.el (c-where-wrt-brace-contruct): Reintroduce 
the use
+       * lisp/progmodes/cc-cmds.el (c-where-wrt-brace-construct): Reintroduce 
the use
        of c-beginning-of-decl-1, which was removed some weeks ago, in place of 
a
        c-syntactic-skip-backward.  Reformulate the code generally.
 
@@ -31051,7 +31051,7 @@
 
 2021-03-28  Lars Ingebrigtsen  <larsi@gnus.org>
 
-       Clarify the doc string of plist-memeber and plist-put
+       Clarify the doc string of plist-member and plist-put
 
        * src/fns.c (Fplist_member):
        (Fplist_put): Clarify what comparison function is used for PROP
@@ -35236,7 +35236,7 @@
 
 2021-03-04  Andrea Corallo  <akrl@sdf.org>
 
-       * src/comp.c (hash_native_abi): Account for 
`system-configuraton-options'.
+       * src/comp.c (hash_native_abi): Account for 
`system-configuration-options'.
 
 2021-03-04  Glenn Morris  <rgm@gnu.org>
 
@@ -46491,7 +46491,7 @@
 
        Fix Quit button in dictionary buffer
 
-       * lisp/net/dictionary.el (dictionay-close): Changing the arity of the
+       * lisp/net/dictionary.el (dictionary-close): Changing the arity of the
        function in cc5f2803785c5dc785f09a292313cf799e8d29bb was a mistake.
        Restore it, but mark the argument as unused to avoid a
        wrong-number-of-arguments error when using the Quit button.
@@ -80628,7 +80628,7 @@
 
 2020-05-17  Andrea Corallo  <akrl@sdf.org>
 
-       Fix Garbage Collector for missing calle-saved regs content (Bug#41357)
+       Fix Garbage Collector for missing callee-saved regs content (Bug#41357)
 
        * src/alloc.c (SET_STACK_TOP_ADDRESS): Do not call
        __builtin_unwind_init.
@@ -88998,7 +88998,7 @@
 
 2020-01-19  Stefan Kangas  <stefankangas@gmail.com>
 
-       Make arguments to dired-chage-marks non-optional
+       Make arguments to dired-change-marks non-optional
 
        * lisp/dired.el (dired-change-marks): Make arguments
        non-optional.  (Bug#29842)
@@ -103735,7 +103735,7 @@
 
        Fixes bug#38131.
 
-       This is not the best way to have fido-mdoe emulate that particular bit
+       This is not the best way to have fido-mode emulate that particular bit
        of ido-mode.
 
        This reverts commit 5761a1a3939e23d8e8c725241dd9398a12f191b0.
@@ -118445,7 +118445,7 @@
        internal variable...
        (browse-url-browser-function, browse-url-external-browser): Used
        by these two; the latter of which is a new variable.
-       (browse-url-botton-regexp): New variable.
+       (browse-url-button-regexp): New variable.
        (browse-url-button-map): New keymap.
        (browse-url-button): New face.
        (browse-url-add-buttons): New function to add clickable browse-url
@@ -139023,7 +139023,7 @@
        Add 'breakpoint' to builtins for Python
 
        * lisp/progmodes/python.el (python-font-lock-keywords-level-2)
-       (python-font-lock-keywords-maxiumum-decoration): Add 'breakpoint'
+       (python-font-lock-keywords-maximum-decoration): Add 'breakpoint'
        to the list of builtins, it's new as of Python 3.7.
 
 2019-03-01  Eli Zaretskii  <eliz@gnu.org>
@@ -143055,7 +143055,7 @@
 
 2019-01-05  João Távora  <joaotavora@gmail.com>
 
-       New flymake-supress-zero-counters defcustom
+       New flymake-suppress-zero-counters defcustom
 
        A feature suggested by Yuri Khan <yurivkhan@gmail.com>.
 
@@ -185861,7 +185861,7 @@
        (flymake-start-syntax-check-on-find-file): Obsolete alias for
        flymake-start-on-flymake-mode.
        (flymake-start): Redesign.  Affect the global post-command-hook
-       and local window-configuraiton-change-hook.
+       and local window-configuration-change-hook.
        (flymake--schedule-timer-maybe)
        (flymake-after-change-function, flymake-after-save-hook): Pass
        t to flymake-start.
@@ -190903,7 +190903,7 @@
        (initFrameFromEmacs) [NS_IMPL_COCOA]: Handle ns-appearance and
        ns-transparent-titlebar frame parameters.
        * doc/lispref/frames.texi (Window Management Parameters): Document
-       ns-apperance and ns-transparent-titlebar.
+       ns-appearance and ns-transparent-titlebar.
 
 2017-08-22  Alan Mackenzie  <acm@muc.de>
 
@@ -204016,7 +204016,7 @@
 
 2017-04-02  Michael Albinus  <michael.albinus@gmx.de>
 
-       Apply connecion-local variables for shells
+       Apply connection-local variables for shells
 
        * doc/misc/tramp.texi (Remote processes): Show use of connection-local
        variables.  Don't mention Emacs 23 anymore.
@@ -204027,7 +204027,7 @@
        (connection-local-set-profiles, with-connection-local-profiles):
        Adapt docstring.
 
-       * lisp/shell.el (shell): Apply connecion-local variables.
+       * lisp/shell.el (shell): Apply connection-local variables.
 
 2017-04-01  Evgeni Kolev  <evgenysw@gmail.com>  (tiny change)
 
@@ -206673,7 +206673,7 @@
        * lisp/emacs-lisp/package.el (package-initialize): Check
        `after-init-time' rather than `load-file-name' to decide if
        `package--ensure-init-file' should be called.  Depending on
-       `load-file-name' will fail if the user calls `pacakge-initialize' in
+       `load-file-name' will fail if the user calls `package-initialize' in
        file which is loaded from the init file (Bug#24643, Bug#25819).
 
 2017-02-26  Eli Zaretskii  <eliz@gnu.org>
@@ -229958,7 +229958,7 @@
        Use #' read syntax for functions.
        (file-notify-test05-dir-validity)
        (file-notify-test06-many-events): Simplify directory creation.
-       (file-notify-test09-sufficient-ressources): New test.
+       (file-notify-test09-sufficient-resources): New test.
 
 2016-03-04  Lars Ingebrigtsen  <larsi@gnus.org>
 
@@ -231088,7 +231088,7 @@
        * lisp/gnus/gnus-rfc1843.el: New file for Gnus/rfc1843
        interface functions.
 
-       * lisp/gnus/gnus-rfc1843.el: Move all Gnus-specifig functions to
+       * lisp/gnus/gnus-rfc1843.el: Move all Gnus-specific functions to
        gnus-rfc1843.
 
 2016-02-22  Lars Ingebrigtsen  <larsi@gnus.org>
diff --git a/doc/lispref/ChangeLog.1 b/doc/lispref/ChangeLog.1
index 7c7d49967c..82840aed1d 100644
--- a/doc/lispref/ChangeLog.1
+++ b/doc/lispref/ChangeLog.1
@@ -886,7 +886,7 @@
 2014-03-15  Dmitry Gutov  <dgutov@yandex.ru>
 
        * display.texi (Blinking): Update WRT to the new
-       `blink-matchin-paren' behavior.
+       `blink-matching-paren' behavior.
 
 2014-03-14  Martin Rudalics  <rudalics@gmx.at>
 
diff --git a/doc/lispref/modes.texi b/doc/lispref/modes.texi
index c472f9b441..9ff9614a66 100644
--- a/doc/lispref/modes.texi
+++ b/doc/lispref/modes.texi
@@ -5015,7 +5015,7 @@ expression @code{treesit-comment-start} 
(@pxref{Tree-sitter major
 modes, treesit-comment-start}).  This function assumes @var{parent} is
 the comment node.
 
-@item coment-start-skip
+@item comment-start-skip
 This anchor is a function that is called with 3 arguments: @var{node},
 @var{parent}, and @var{bol}, and returns the position after the
 comment-start token and any whitespace characters following that
diff --git a/doc/lispref/sequences.texi b/doc/lispref/sequences.texi
index bc5a4cf24a..58f2703c8b 100644
--- a/doc/lispref/sequences.texi
+++ b/doc/lispref/sequences.texi
@@ -719,7 +719,7 @@ calling @var{function} on the elements in @var{sequence}.
 then with that result and the third element of @var{sequence}, etc.
 @var{function} should be a function of two arguments.
 
-@var{function} is called with two arguments.  @var{intial-value}
+@var{function} is called with two arguments.  @var{initial-value}
 (and then the accumulated value) is used as the first argument, and
 the elements in @var{sequence} are used for the second argument.
 
diff --git a/lisp/ChangeLog.16 b/lisp/ChangeLog.16
index 1d7684be81..ef230bf9ed 100644
--- a/lisp/ChangeLog.16
+++ b/lisp/ChangeLog.16
@@ -4866,7 +4866,7 @@
 2012-10-12  Fabián Ezequiel Gallina  <fgallina@cuca>
 
        * progmodes/python.el (python-mode-map):
-       Replace subtitute-key-definition with proper command remapping.
+       Replace substitute-key-definition with proper command remapping.
        (python-nav--up-list): Fix behavior for blocks on the same level.
 
 2012-10-11  Stefan Monnier  <monnier@iro.umontreal.ca>
@@ -24325,7 +24325,7 @@
        Pass nil for `after-find-file-from-revert-buffer'.
 
        * saveplace.el (save-place-find-file-hook): Use new variable
-       `rever-buffer-in-progress-p', not `after-find-file-from-revert-buffer'.
+       `revert-buffer-in-progress-p', not `after-find-file-from-revert-buffer'.
 
 2011-04-06  Glenn Morris  <rgm@gnu.org>
 
diff --git a/lisp/ChangeLog.17 b/lisp/ChangeLog.17
index c494f43896..57620513e3 100644
--- a/lisp/ChangeLog.17
+++ b/lisp/ChangeLog.17
@@ -25522,7 +25522,7 @@
 
        * textmodes/ispell.el (ispell-add-per-file-word-list):
        Fix `flyspell-correct-word-before-point' error when accepting
-       words and `coment-padding' is an integer by using
+       words and `comment-padding' is an integer by using
        `comment-normalize-vars' (Bug #14214).
 
 2013-04-17  Fabián Ezequiel Gallina  <fgallina@gnu.org>
diff --git a/lisp/epa-ks.el b/lisp/epa-ks.el
index 4c539b56a3..bb64b61b8f 100644
--- a/lisp/epa-ks.el
+++ b/lisp/epa-ks.el
@@ -109,7 +109,7 @@ When all keys have been selected, use 
\\[epa-ks-do-key-to-fetch] to
 actually import the keys.
 
 When called interactively, `epa-ks-mark-key-to-fetch' will always
-add a \"F\" tag.  Non-interactivly the tag must be specified by
+add a \"F\" tag.  Non-interactively the tag must be specified by
 setting the TAG parameter."
   (interactive (list "F"))
   (if (region-active-p)
diff --git a/lisp/gnus/ChangeLog.2 b/lisp/gnus/ChangeLog.2
index fd5fa0542f..4ac69b575f 100644
--- a/lisp/gnus/ChangeLog.2
+++ b/lisp/gnus/ChangeLog.2
@@ -10070,7 +10070,7 @@
        * gnus-group.el (gnus-group-delete-group): Nix the entry in
        gnus-cache-active-hashtb.
 
-       * gnus-agent.el (gnus-agent-mark-unread-afer-downloaded): New variable.
+       * gnus-agent.el (gnus-agent-mark-unread-after-downloaded): New variable.
        (gnus-agent-summary-fetch-group): Use it.
 
        * gnus-msg.el (gnus-debug-files): New variable.
diff --git a/lisp/gnus/ChangeLog.3 b/lisp/gnus/ChangeLog.3
index 3b41e9edc9..8c1073dc8d 100644
--- a/lisp/gnus/ChangeLog.3
+++ b/lisp/gnus/ChangeLog.3
@@ -6032,7 +6032,7 @@
        Make `default' the default, for compatibility with open-network-stream.
        Handle the no-parameter case exactly as open-network-stream, with no
        additional stream processing.  Search plists using plist-get.
-       Explicitly add :end-of-commend parameter if it is missing.
+       Explicitly add :end-of-comment parameter if it is missing.
        (proto-stream-open-default): Rename from
        proto-stream-open-network-only.  Return 'default as the type.
        (proto-stream-open-starttls): Rename from proto-stream-open-network.
diff --git a/lisp/org/ChangeLog.1 b/lisp/org/ChangeLog.1
index f79d8bf674..4f51c6a1eb 100644
--- a/lisp/org/ChangeLog.1
+++ b/lisp/org/ChangeLog.1
@@ -1867,7 +1867,7 @@
 
        * org.el: Use
        `org-define-obsolete-{function,variable}-alias´instead of
-       `define-obsolate{function,variable}-alias´.
+       `define-obsolete-{function,variable}-alias´.
 
        * org-compat.el (user-error): Defalias to `error´ for Emacsen that
        don't have it.
diff --git a/lisp/progmodes/idlwave.el b/lisp/progmodes/idlwave.el
index cd2fc7c707..395c51d542 100644
--- a/lisp/progmodes/idlwave.el
+++ b/lisp/progmodes/idlwave.el
@@ -133,7 +133,7 @@
 ;;   limited to comments only and occurs only when a comment
 ;;   paragraph is filled via `idlwave-fill-paragraph'.
 ;;
-;;   Muti-statement lines (using "&") on block begin and end lines can
+;;   Multi-statement lines (using "&") on block begin and end lines can
 ;;   ruin the formatting.  For example, multiple end statements on a
 ;;   line: endif & endif.  Using "&" outside of block begin/end lines
 ;;   should be okay.
diff --git a/lisp/progmodes/js.el b/lisp/progmodes/js.el
index 8ec14cf7ad..a776ff91f9 100644
--- a/lisp/progmodes/js.el
+++ b/lisp/progmodes/js.el
@@ -1928,7 +1928,7 @@ This performs fontification according to 
`js--class-styles'."
 ;; identified as such), then the `syntax-propertize' region won’t be
 ;; extended backwards to the start of the JSXOpeningElement:
 ;;
-;;   <div         ← This line wasn’t JSX when last edited.
+;;   <div         ← This line wasn't JSX when last edited.
 ;;     attr="">   ← Despite completing the JSX, the next
 ;;             ^    `syntax-propertize' region wouldn’t magically
 ;;                  extend back a few lines.
@@ -2090,7 +2090,7 @@ JSXElement or a JSXOpeningElement/JSXClosingElement pair."
                         ;; JSXOpeningElement has been found, so keep
                         ;; looking backwards for an enclosing one).
                         (or (not close-tag-pos) (<= start 
close-tag-pos)))))))))
-      ;; Don’t return the last tag pos, as it wasn’t enclosing.
+      ;; Don't return the last tag pos, as it wasn't enclosing.
       (setq tag-beg nil close-tag-pos nil))
     (and tag-beg (list tag-beg-pos tag-end-pos close-tag-pos))))
 
diff --git a/lisp/so-long.el b/lisp/so-long.el
index 661f5ee57a..fc99162325 100644
--- a/lisp/so-long.el
+++ b/lisp/so-long.el
@@ -986,7 +986,7 @@ See also `so-long-mode-line-info'."
 ;; Modes that go slowly and line lengths excessive
 ;; Font-lock performance becoming oppressive
 ;; All of my CPU tied up with strings
-;; These are a few of my least-favourite things
+;; These are a few of my least-favorite things
 
 (defvar-local so-long-original-values nil
   "Alist holding the buffer's original `major-mode' value, and other data.
diff --git a/lisp/textmodes/toml-ts-mode.el b/lisp/textmodes/toml-ts-mode.el
index 26a3eb69d8..bca6a5e81a 100644
--- a/lisp/textmodes/toml-ts-mode.el
+++ b/lisp/textmodes/toml-ts-mode.el
@@ -159,7 +159,7 @@ the subtrees."
 
     ;; Comments
     (setq-local comment-start "# ")
-    (setq-local commend-end "")
+    (setq-local comment-end "")
 
     ;; Indent.
     (setq-local treesit-simple-indent-rules toml-ts-mode--indent-rules)
diff --git a/oldXMenu/ChangeLog.1 b/oldXMenu/ChangeLog.1
index ebbbcd2df2..b739a231f5 100644
--- a/oldXMenu/ChangeLog.1
+++ b/oldXMenu/ChangeLog.1
@@ -46,7 +46,7 @@
 
        * Makefile.in (mostlyclean, clean, distclean, maintainer-clean, tags):
        Declare as PHONY.
-       (boostrap-clean): New.
+       (bootstrap-clean): New.
 
 2013-10-24  Glenn Morris  <rgm@gnu.org>
 
diff --git a/src/ChangeLog.12 b/src/ChangeLog.12
index 7f77c0ca07..f455c4de38 100644
--- a/src/ChangeLog.12
+++ b/src/ChangeLog.12
@@ -10836,7 +10836,7 @@
        * gtkutil.c (xg_maybe_add_timer): Port to higher-res time stamps.
 
        * image.c (prepare_image_for_display, clear_image_cache)
-       (lookup_image): Port to higer-resolution time stamps.
+       (lookup_image): Port to higher-resolution time stamps.
 
        * keyboard.c (start_polling, bind_polling_period):
        Check for time stamp overflow.
diff --git a/src/ChangeLog.13 b/src/ChangeLog.13
index 91f8005ac5..0c4e2909ce 100644
--- a/src/ChangeLog.13
+++ b/src/ChangeLog.13
@@ -10579,7 +10579,7 @@
        (../src/$(OLDXMENU), $(OLDXMENU)): Remove.
        (temacs$(EXEEXT)): Depend on $(LIBXMENU), not stamp-oldxmenu.
        ($(lwlibdir)/liblw.a, $(oldXMenudir)/libXMenu11.a, FORCE): New targets.
-       (boostrap-clean): No need to remove stamp-oldxmenu.
+       (bootstrap-clean): No need to remove stamp-oldxmenu.
 
        Fix recently introduced bool vector overrun.
        This was due to an optimization that went awry.
diff --git a/src/fns.c b/src/fns.c
index d8744c1a4d..b6e871ad49 100644
--- a/src/fns.c
+++ b/src/fns.c
@@ -3938,7 +3938,7 @@ system.
 If the region can't be decoded, signal an error and don't modify the buffer.
 Optional third argument BASE64URL determines whether to use the URL variant
 of the base 64 encoding, as defined in RFC 4648.
-If optional fourth argument INGORE-INVALID is non-nil invalid characters
+If optional fourth argument IGNORE-INVALID is non-nil invalid characters
 are ignored instead of signaling an error.  */)
      (Lisp_Object beg, Lisp_Object end, Lisp_Object base64url,
       Lisp_Object ignore_invalid)
diff --git a/test/lisp/delim-col-tests.el b/test/lisp/delim-col-tests.el
index 97fa0f1e8f..2bf54d9b44 100644
--- a/test/lisp/delim-col-tests.el
+++ b/test/lisp/delim-col-tests.el
@@ -100,7 +100,7 @@
                             "aaa       [ bbb, cccc    ]        dddd\n"
                             "aa        [ bb,  ccccccc ]        ddd\n"))))))
 
-(ert-deftest delim-col-tests-delimit-colummns-before-after ()
+(ert-deftest delim-col-tests-delimit-columns-before-after ()
   (let ((delimit-columns-before "<")
         (delimit-columns-after ">"))
     (with-temp-buffer
diff --git a/test/lisp/emacs-lisp/cconv-tests.el 
b/test/lisp/emacs-lisp/cconv-tests.el
index e666fe0a4c..537f6bfe72 100644
--- a/test/lisp/emacs-lisp/cconv-tests.el
+++ b/test/lisp/emacs-lisp/cconv-tests.el
@@ -60,7 +60,7 @@
                    "cl-defun documentation"))
   (should (eq (cconv-tests-cl-defun) 'cl-defun-result)))
 
-;; FIXME: The byte-complier croaks on this.  See Bug#28557.
+;; FIXME: The byte-compiler croaks on this.  See Bug#28557.
 ;; (defmacro cconv-tests-defmacro ()
 ;;   (:documentation (concat "defmacro" " documentation"))
 ;;   '(quote defmacro-result))
@@ -70,7 +70,7 @@
 ;;                    "defmacro documentation"))
 ;;   (should (eq (cconv-tests-defmacro) 'defmacro-result)))
 
-;; FIXME: The byte-complier croaks on this.  See Bug#28557.
+;; FIXME: The byte-compiler croaks on this.  See Bug#28557.
 ;; (cl-defmacro cconv-tests-cl-defmacro ()
 ;;   (:documentation (concat "cl-defmacro" " documentation"))
 ;;   '(quote cl-defmacro-result))
diff --git a/test/lisp/emacs-lisp/checkdoc-tests.el 
b/test/lisp/emacs-lisp/checkdoc-tests.el
index 289476f024..c17415cbdd 100644
--- a/test/lisp/emacs-lisp/checkdoc-tests.el
+++ b/test/lisp/emacs-lisp/checkdoc-tests.el
@@ -130,25 +130,25 @@ See the comments in Bug#24998."
     (re-search-forward goto-string)
     (checkdoc-in-abbreviation-p (point))))
 
-(ert-deftest checkdoc-tests-in-abbrevation-p/basic-case ()
+(ert-deftest checkdoc-tests-in-abbreviation-p/basic-case ()
   (should (checkdoc-tests--abbrev-test "foo bar e.g. baz" "e.g"))
   (should (checkdoc-tests--abbrev-test "behavior/errors etc. that" "etc"))
   (should (checkdoc-tests--abbrev-test "foo vs. bar" "vs"))
   (should (checkdoc-tests--abbrev-test "spy a.k.a. spy" "a.k.a")))
 
-(ert-deftest checkdoc-tests-in-abbrevation-p/with-parens ()
+(ert-deftest checkdoc-tests-in-abbreviation-p/with-parens ()
   (should (checkdoc-tests--abbrev-test "foo bar (e.g. baz)" "e.g")))
 
-(ert-deftest checkdoc-tests-in-abbrevation-p/with-escaped-parens ()
+(ert-deftest checkdoc-tests-in-abbreviation-p/with-escaped-parens ()
   (should (checkdoc-tests--abbrev-test "foo\n\\(e.g. baz)" "e.g")))
 
-(ert-deftest checkdoc-tests-in-abbrevation-p/single-char ()
+(ert-deftest checkdoc-tests-in-abbreviation-p/single-char ()
   (should (checkdoc-tests--abbrev-test "a. foo bar" "a")))
 
-(ert-deftest checkdoc-tests-in-abbrevation-p/with-em-dash ()
+(ert-deftest checkdoc-tests-in-abbreviation-p/with-em-dash ()
   (should (checkdoc-tests--abbrev-test "foo bar baz---e.g." "e.g")))
 
-(ert-deftest checkdoc-tests-in-abbrevation-p/incorrect-abbreviation ()
+(ert-deftest checkdoc-tests-in-abbreviation-p/incorrect-abbreviation ()
   (should-not (checkdoc-tests--abbrev-test "foo bar a.b.c." "a.b.c")))
 
 (defun checkdoc-test-error-format-is-good (msg &optional reverse literal)
diff --git a/test/lisp/emacs-lisp/find-func-tests.el 
b/test/lisp/emacs-lisp/find-func-tests.el
index d18a9dc1a9..8c432f8720 100644
--- a/test/lisp/emacs-lisp/find-func-tests.el
+++ b/test/lisp/emacs-lisp/find-func-tests.el
@@ -87,7 +87,7 @@ expected function symbol and function library, respectively."
   (test-locate-helper #'forward-char '(forward-char . "cmds.c"))
   (should-error (test-locate-helper 'wrong-function)))
 
-(ert-deftest find-func-tests--locate-adviced-symbols ()
+(ert-deftest find-func-tests--locate-advised-symbols ()
   (defun my-message ()
     (message "Hello!"))
   (advice-add #'mark-sexp :around 'my-message)
diff --git a/test/lisp/erc/resources/services/auth-source/recon.eld 
b/test/lisp/erc/resources/services/auth-source/recon.eld
index 40ea3c9157..2ab52c9bec 100644
--- a/test/lisp/erc/resources/services/auth-source/recon.eld
+++ b/test/lisp/erc/resources/services/auth-source/recon.eld
@@ -21,7 +21,7 @@
  (0.00 ":irc.foonet.net 376 tester :End of message of the day."))
 
 ((mode-a 10 "MODE tester +i")
- (0.00 ":irc.foonet.net 501 tester x :is not a recognised user mode.")
+ (0.00 ":irc.foonet.net 501 tester x :is not a recognized user mode.")
  (0.04 ":tester!tester@10.0.2.100 MODE tester :+i")
  (0.00 ":NickServ!NickServ@services.int NOTICE tester :This nickname is 
registered. Please choose a different nickname, or identify via \2/msg NickServ 
identify <password>\2."))
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/treesit.el b/lisp/treesit.el
index 353a9bc12c..74476f1861 100644
--- a/lisp/treesit.el
+++ b/lisp/treesit.el
@@ -1977,9 +1977,9 @@ in `treesit-parser-list'."
                    collect node))
          (largest-node (car (last node-list)))
          (parent (treesit-node-parent largest-node))
          ;; node-list-acending contains all the node bottom-up, then
          ;; the parent.
-         (node-list-acending
+         (node-list-ascending
           (if (null largest-node)
               ;; If there are no nodes that start at point, just show
               ;; the node at point and its parent.
@@ -1990,7 +1990,7 @@ in `treesit-parser-list'."
          (name ""))
     ;; We draw nodes like (parent field-name: (node)) recursively,
     ;; so it could be (node1 field-name: (node2 field-name: (node3))).
-    (dolist (node node-list-acending)
+    (dolist (node node-list-ascending)
       (setq
        name
        (concat
@@ -1977,9 +1977,9 @@ in `treesit-parser-list'."
          (largest-node (car (last node-list)))
          (parent (treesit-node-parent largest-node))
-         ;; node-list-acending contains all the node bottom-up, then
+         ;; node-list-ascending contains all the node bottom-up, then
          ;; the parent.